# Contributors to Eclipse zenoh

These are the contributors to Eclipse zenoh (the initial contributors and the contributors listed in the Git log).


| GitHub username | Name                         |
| --------------- | -----------------------------|
| kydos           | Angelo Corsaro (ADLINK)      |
| JEnoch          | Julien Enoch (ADLINK)        |
| OlivierHecart   | Olivier Hécart (ADLINK)      |
| gabrik          | Gabriele Baldoni (ADLINK)    |
| Mallets         | Luca Cominardi (ADLINK)      |                 
| IvanPaez        | Ivan Paez (ADLINK)           |            
